local SmokeHouse = ...

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = "SMOKE_HOUSE_V3_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = "SMOKE_HOUSE_V3_FUNCTION_LIST"
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = "SMOKE_HOUSE_V3_FUNCTION_LIST",
                AssetFunctionList = {
                        "SMOKE_HOUSE_V3_FISH_FUNCTION",
                        "SMOKE_HOUSE_V3_BOAR_FUNCTION"
                }
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = "SMOKE_HOUSE_V3_FISH_FUNCTION",
                Name = "SMOKE_HOUSE_V3_FISH_FUNCTION_NAME",
                TypeList = { "FOOD" },
                IsOverrideCapacity = true,
                CapacityPerSlot = 50,
		WorkerCapacity = 1,
                RelatedJob = { Job = "FISHERMAN", Behavior = "WORK_BEHAVIOR" },
                InputInventoryCapacity = {
			{ Resource = "FISH", Quantity = 50 },
                	{ Resource = "SALT2", Quantity = 50 },
                	{ Resource = "WOOD", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = "FISH", Quantity = 4 },
                	{ Resource = "SALT2", Quantity = 1 },
                	{ Resource = "WOOD", Quantity = 2 }
                },
                ResourceProduced = {
			{ Resource = "SMOKE_HOUSE_V3_SALTING", Quantity = 4 }
                }
})

SmokeHouse:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = "SMOKE_HOUSE_V3_BOAR_FUNCTION",
                Name = "SMOKE_HOUSE_V3_BOAR_FUNCTION_NAME",
                TypeList = { "FOOD" },
                IsOverrideCapacity = true,
                CapacityPerSlot = 50,
		WorkerCapacity = 1,
                RelatedJob = { Job = "HUNTER", Behavior = "WORK_BEHAVIOR" },
                InputInventoryCapacity = {
			{ Resource = "BOAR", Quantity = 50 },
                	{ Resource = "SALT2", Quantity = 50 },
                	{ Resource = "WOOD", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = "BOAR", Quantity = 1 },
                	{ Resource = "SALT2", Quantity = 1 },
                	{ Resource = "WOOD", Quantity = 2 }
                },
                ResourceProduced = {
			{ Resource = "SMOKE_HOUSE_V3_SALTING", Quantity = 4 }
                }
})

function registerSmokeHouse(_nameFbx, _nameAsset)
    -- Apply building asset processor
    SmokeHouse:registerAssetProcessor("models/SmokeHouse" .. _nameFbx .. ".fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

    -- Register prefab nodes (currently only one core model)
    SmokeHouse:registerAssetId("models/SmokeHouse" .. _nameFbx .. ".fbx/Prefab/smokeHousePart", "SMOKE_HOUSE_V3_" .. _nameAsset .. "_WORKPLACE_PREFAB")

    -- Register the carbon smoke house part
    SmokeHouse:register({
	DataType = "BUILDING_PART",
	Id = "SMOKE_HOUSE_V3_" .. _nameAsset .. "_WORKPLACE_PART",
	Name = "SMOKE_HOUSE_V3_" .. _nameAsset .. "_WORKPLACE_NAME",
	Description = "SMOKE_HOUSE_V3_" .. _nameAsset .. "_WORKPLACE_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "SMOKE_HOUSE_V3_" .. _nameAsset .. "_WORKPLACE_PREFAB"
	},
        --Ca c'est pour dclarer le visuel de construction si il y en a un !
	ConstructionVisual = "SMOKE_HOUSE_V3_" .. _nameAsset .. "_WORKPLACE_PREFAB",
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = 10 }
		}
	},
        VillagerCapacity = 1,
  	AssetBuildingFunction = "SMOKE_HOUSE_V3_ASSIGNABLE_FUNCTION"
    })

    -- Register air vent particle system
    SmokeHouse:registerAssetId("models/SmokeHouse" .. _nameFbx .. ".fbx/Prefab/smokeHousePart/step_2/cheminee/SmokeEmitter", "SMOKE_HOUSE_V3_" .. _nameAsset .. "_EMITTER_PREFAB")
 
    SmokeHouse:registerPrefabComponent("models/SmokeHouse" .. _nameFbx .. ".fbx/Prefab/smokeHousePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 8, 8 },
	FeedbackComponentListToActivate = {
                 { "SMOKE_HOUSE_V3_" .. _nameAsset .. "_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
    })

    SmokeHouse:registerPrefabComponent("models/SmokeHouse" .. _nameFbx .. ".fbx/Prefab/smokeHousePart/step_2/cheminee/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_HOUSING_SMOKE",
	IsPlaying = true,
	IsEmitting = false
    })

    SmokeHouse:registerPrefabComponent("models/SmokeHouse" .. _nameFbx .. ".fbx/Prefab/smokeHousePart/step_2/cheminee/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
    })
end

registerSmokeHouse("Carbon", "CARBON")
registerSmokeHouse("Brown", "BROWN")
